@@ -364,5 +364,5 @@ class AsyncClient:
         return await self.stubDerivativeExchange.SubaccountTradesList(req)
 
     async def get_funding_payments(self, subaccount_id: str, **kwargs):
-        req = derivative_exchange_rpc_pb.FundingPaymentsRequest(subaccount_id=subaccount_id, market_id=kwargs.get("market_id"))
+        req = derivative_exchange_rpc_pb.FundingPaymentsRequest(subaccount_id=subaccount_id, market_id=kwargs.get("market_id"), skip=kwargs.get("skip"), limit=kwargs.get("limit"))
         return await self.stubDerivativeExchange.FundingPayments(req)
\ No newline at end of file
